@@ -1,7 +1,7 @@
 package Bencher::Scenario::GetoptModules;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,11 +42,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::GetoptModules
+Bencher::Scenario::GetoptModules - Benchmark some popular Perl Getopt modules
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::GetoptModules (from Perl distribution Bencher-Scenario-GetoptModules), released on 2016-01-05.
+This document describes version 0.04 of Bencher::Scenario::GetoptModules (from Perl distribution Bencher-Scenario-GetoptModules), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -58,17 +58,19 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 BENCHMARKED MODULES
 
-L<Getopt::Long> 2.45
+Version numbers shown below are the versions used when running the sample benchmark.
+
+L<Getopt::Long> 2.49
 
 L<Getopt::Long::Less> 0.06
 
 L<Getopt::Long::EvenLess> 0.04
 
-L<Getopt::Long::Complete> 0.26
+L<Getopt::Long::Complete> 0.27
 
 L<Getopt::Long::Descriptive> 0.099
 
-L<Getopt::Long::Subcommand> 0.04
+L<Getopt::Long::Subcommand> 0.05
 
 L<Getopt::Std> 1.11
 
@@ -76,7 +78,7 @@ L<MooseX::Getopt> 0.68
 
 L<Getopt::ArgvFile> 1.11
 
-L<Getopt::Lucid> 1.05
+L<Getopt::Lucid> 1.06
 
 L<Getopt::Panjang> 0.04
 
@@ -86,37 +88,37 @@ L<Getopt::Std::Strict> 1.01
 
 =over
 
-=item * Getopt::Long (perl_code)
+=item * Getopt::Long (perl_code) [getopt-long]
 
 L<Getopt::Long>
 
 
 
-=item * Getopt::Long::Less (perl_code)
+=item * Getopt::Long::Less (perl_code) [getopt-long]
 
 L<Getopt::Long::Less>
 
 
 
-=item * Getopt::Long::EvenLess (perl_code)
+=item * Getopt::Long::EvenLess (perl_code) [getopt-long]
 
 L<Getopt::Long::EvenLess>
 
 
 
-=item * Getopt::Long::Complete (perl_code)
+=item * Getopt::Long::Complete (perl_code) [getopt-long]
 
 L<Getopt::Long::Complete>
 
 
 
-=item * Getopt::Long::Descriptive (perl_code)
+=item * Getopt::Long::Descriptive (perl_code) [getopt-long]
 
 L<Getopt::Long::Descriptive>
 
 
 
-=item * Getopt::Long::Subcommand (perl_code)
+=item * Getopt::Long::Subcommand (perl_code) [getopt-long]
 
 L<Getopt::Long::Subcommand>
 
@@ -128,7 +130,7 @@ L<Getopt::Std>
 
 
 
-=item * MooseX::Getopt (perl_code)
+=item * MooseX::Getopt (perl_code) [moox]
 
 L<MooseX::Getopt>
 
@@ -162,27 +164,27 @@ L<Getopt::Std::Strict>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m GetoptModules >>):
 
- +-----+---------------------------+-----------+-------------------+---------+---------+
- | seq | name                      | time      | mod_overhead_time | errors  | samples |
- +-----+---------------------------+-----------+-------------------+---------+---------+
- | 8   | MooseX::Getopt            | 2.5e+02ms | 2.5e+02ms         | 0.0022  | 20      |
- | 5   | Getopt::Long::Descriptive | 38ms      | 33ms              | 0.00017 | 20      |
- | 10  | Getopt::Lucid             | 28.4ms    | 23.6ms            | 5.3e-05 | 20      |
- | 9   | Getopt::ArgvFile          | 22ms      | 17ms              | 7.1e-05 | 20      |
- | 1   | Getopt::Long              | 17.6ms    | 12.7ms            | 3.4e-05 | 20      |
- | 6   | Getopt::Long::Subcommand  | 13.9ms    | 9.08ms            | 2.8e-05 | 20      |
- | 12  | Getopt::Std::Strict       | 11ms      | 6.1ms             | 3.9e-05 | 20      |
- | 4   | Getopt::Long::Complete    | 8.1ms     | 3.3ms             | 3.9e-05 | 22      |
- | 2   | Getopt::Long::Less        | 7.5ms     | 2.6ms             | 3.8e-05 | 20      |
- | 11  | Getopt::Panjang           | 6.8ms     | 2ms               | 2.2e-05 | 20      |
- | 7   | Getopt::Std               | 6.7ms     | 1.8ms             | 7.1e-05 | 20      |
- | 3   | Getopt::Long::EvenLess    | 5.8ms     | 0.99ms            | 2e-05   | 20      |
- | 0   | perl -e1 (baseline)       | 4.8ms     | 0ms               | 3.4e-05 | 20      |
- +-----+---------------------------+-----------+-------------------+---------+---------+
+ +---------------------------+-----------+------------------------+------------+----------+---------+
+ | participant               | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors  | samples |
+ +---------------------------+-----------+------------------------+------------+----------+---------+
+ | MooseX::Getopt            |     160   |                  157.5 |        1   |   0.0003 |      20 |
+ | Getopt::Long::Descriptive |      26   |                   23.5 |        6.2 | 5.3e-05  |      20 |
+ | Getopt::Lucid             |      20   |                   17.5 |        8.3 | 3.6e-05  |      20 |
+ | Getopt::ArgvFile          |      15   |                   12.5 |       11   | 9.4e-05  |      20 |
+ | Getopt::Long              |      11   |                    8.5 |       14   | 4.4e-05  |      20 |
+ | Getopt::Long::Subcommand  |       9.4 |                    6.9 |       17   | 3.4e-05  |      20 |
+ | Getopt::Std::Strict       |       6.8 |                    4.3 |       24   | 5.3e-05  |      20 |
+ | Getopt::Long::Complete    |       5   |                    2.5 |       33   |   4e-05  |      20 |
+ | Getopt::Long::Less        |       4.6 |                    2.1 |       35   | 2.7e-05  |      20 |
+ | Getopt::Panjang           |       4   |                    1.5 |       40   | 6.2e-05  |      20 |
+ | Getopt::Long::EvenLess    |       4   |                    1.5 |       40   | 6.1e-05  |      20 |
+ | Getopt::Std               |       3.8 |                    1.3 |       43   | 3.1e-05  |      20 |
+ | perl -e1 (baseline)       |       2.5 |                    0   |       64   |   1e-05  |      20 |
+ +---------------------------+-----------+------------------------+------------+----------+---------+
 
 =head1 DESCRIPTION
 
